platformLazyNullable<T> method

T? platformLazyNullable<T>({
  1. ValueGetter<T>? material,
  2. ValueGetter<T>? cupertino,
})

Returns the platform-appropriate nullable value of type T, lazily evaluated.

Only the getter for the current platform is invoked. Returns null if the getter for the current platform is null.

Implementation

T? platformLazyNullable<T>({ValueGetter<T>? material, ValueGetter<T>? cupertino}) =>
    _valueProviderNullable(material: material, cupertino: cupertino)?.call();