MaterialAlertDialogData class final

Material-specific configuration for a platform alert dialog.

Maps to properties of AlertDialog on Android.

Constructors

MaterialAlertDialogData({Widget? title, Widget? content, List<Widget>? actions, Key? widgetKey, Widget? icon, EdgeInsetsGeometry? iconPadding, Color? iconColor, EdgeInsetsGeometry? titlePadding, TextStyle? titleTextStyle, EdgeInsetsGeometry? contentPadding, TextStyle? contentTextStyle, EdgeInsetsGeometry? actionsPadding, MainAxisAlignment? actionsAlignment, OverflowBarAlignment? actionsOverflowAlignment, VerticalDirection? actionsOverflowDirection, double? actionsOverflowButtonSpacing, EdgeInsetsGeometry? buttonPadding, Color? backgroundColor, double? elevation, Color? shadowColor, Color? surfaceTintColor, String? semanticLabel, EdgeInsets? insetPadding, Clip? clipBehavior, ShapeBorder? shape, AlignmentGeometry? alignment, BoxConstraints? constraints, bool scrollable = kDefaultScrollable})
Creates Material-specific alert dialog configuration.
const

Properties

actions List<Widget>?
A list of widgets to display as actions at the bottom of the dialog.
finalinherited
actionsAlignment MainAxisAlignment?
Alignment of the actions along the main axis.
final
actionsOverflowAlignment OverflowBarAlignment?
Alignment of overflowing actions.
final
actionsOverflowButtonSpacing double?
Spacing between overflowing action buttons.
final
actionsOverflowDirection VerticalDirection?
Direction for overflowing actions.
final
actionsPadding EdgeInsetsGeometry?
Padding around the actions.
final
alignment AlignmentGeometry?
Alignment of the dialog within the screen.
final
backgroundColor Color?
Background color of the dialog.
final
buttonPadding EdgeInsetsGeometry?
Padding around each action button.
final
clipBehavior Clip?
Clip behavior for the dialog content.
final
constraints BoxConstraints?
Optional size constraints for the dialog.
final
content Widget?
The main content of the dialog.
finalinherited
contentPadding EdgeInsetsGeometry?
Padding around the content.
final
contentTextStyle TextStyle?
Text style for the content.
final
elevation double?
Elevation of the dialog surface.
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget?
An optional icon displayed at the top of the dialog.
final
iconColor Color?
Color of the icon.
final
iconPadding EdgeInsetsGeometry?
Padding around the icon.
final
insetPadding EdgeInsets?
Inset padding for the dialog from screen edges.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollable bool
Whether the dialog's content is scrollable.
final
semanticLabel String?
Semantic label for accessibility.
final
shadowColor Color?
Shadow color of the dialog.
final
shape ShapeBorder?
Shape of the dialog border.
final
surfaceTintColor Color?
Surface tint color of the dialog.
final
title Widget?
A title to display at the top of the dialog.
finalinherited
titlePadding EdgeInsetsGeometry?
Padding around the title.
final
titleTextStyle TextStyle?
Text style for the title.
final
widgetKey Key?
A key to identify the widget.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

kDefaultScrollable → const bool
Default value for scrollable.