MaterialDatePickerData class final

Material-specific configuration for the platform date picker.

Maps to parameters of showDatePicker on Android.

Constructors

MaterialDatePickerData({Offset? anchorPoint, Color? barrierColor, bool? barrierDismissible = kMaterialBarrierDismissible, RouteSettings? routeSettings, bool? useRootNavigator, SelectableDayPredicate? selectableDayPredicate, TransitionBuilder? builder, DateTime? currentDate, DatePickerEntryMode initialEntryMode = kDefaultInitialEntryMode, String? helpText, String? cancelText, String? confirmText, Locale? locale, String? barrierLabel, TextDirection? textDirection, DatePickerMode initialDatePickerMode = kDefaultInitialDatePickerMode, String? errorFormatText, String? errorInvalidText, String? fieldHintText, String? fieldLabelText, TextInputType? keyboardType, ValueChanged<DatePickerEntryMode>? onDatePickerModeChange, Icon? switchToInputEntryModeIcon, Icon? switchToCalendarEntryModeIcon, CalendarDelegate<DateTime> calendarDelegate = kDefaultCalendarDelegate})
Creates Material-specific date picker configuration.
const

Properties

anchorPoint Offset?
finalinherited
barrierColor Color?
finalinherited
barrierDismissible bool?
finalinherited
barrierLabel String?
Semantic label for the barrier.
final
builder TransitionBuilder?
finalinherited
calendarDelegate CalendarDelegate<DateTime>
The calendar delegate used for date calculations.
final
cancelText String?
Text for the cancel button.
final
confirmText String?
Text for the confirm button.
final
currentDate DateTime?
The date to highlight as the current date.
final
errorFormatText String?
Error text shown when the date format is invalid.
final
errorInvalidText String?
Error text shown when the date is not selectable.
final
fieldHintText String?
Hint text for the date input field.
final
fieldLabelText String?
Label text for the date input field.
final
hashCode int
The hash code for this object.
no setterinherited
helpText String?
Help text displayed at the top of the picker.
final
initialDatePickerMode DatePickerMode
The initial display mode of the calendar (day or year).
final
initialEntryMode DatePickerEntryMode
The initial entry mode of the date picker (calendar or input).
final
keyboardType TextInputType?
Keyboard type for the date input field.
final
locale Locale?
Locale used for formatting dates.
final
onDatePickerModeChange ValueChanged<DatePickerEntryMode>?
Callback when the date picker entry mode changes.
final
routeSettings RouteSettings?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectableDayPredicate SelectableDayPredicate?
finalinherited
switchToCalendarEntryModeIcon Icon?
Icon for switching to calendar entry mode.
final
switchToInputEntryModeIcon Icon?
Icon for switching to input entry mode.
final
textDirection TextDirection?
Text direction for the picker.
final
useRootNavigator bool?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited