CupertinoMenuPickerData class final

Cupertino-specific configuration for a platform menu picker.

Maps to properties of the Cupertino-style picker on iOS.

Constructors

CupertinoMenuPickerData({Widget? leadingIcon, String? labelText, Color? backgroundColor})
Creates Cupertino-specific menu picker configuration.
const
CupertinoMenuPickerData.iconButton({Widget? leadingIcon, Color? backgroundColor})
Creates Cupertino-specific menu picker configuration for the icon button variant instead of the normal full-width button.
const

Properties

backgroundColor Color?
Background color of the picker.
final
hashCode int
The hash code for this object.
no setterinherited
labelText String?
finalinherited
leadingIcon Widget?
Creates a _PlatformMenuPickerData.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useIconButtonVariant bool
Whether to use the icon button variant.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

kDefaultUseIconButtonVariant → const bool
Default value for useIconButtonVariant.