MaterialMenuPickerData class final

Material-specific configuration for a platform menu picker.

Maps to properties of DropdownMenu on Android.

Constructors

MaterialMenuPickerData({Widget? leadingIcon, String? labelText, EdgeInsetsGeometry? expandedInsets, bool showTrailingIcon = kDefaultShowTrailingIcon, InputDecorationThemeData? inputDecorationThemeData})
Creates Material-specific menu picker configuration.
const
MaterialMenuPickerData.iconButton({Widget? leadingIcon, EdgeInsetsGeometry? expandedInsets})
Creates Material-specific menu picker configuration allowing for just an icon button instead of the normal text-field.
const

Properties

expandedInsets EdgeInsetsGeometry?
Insets applied when the dropdown menu is expanded.
final
hashCode int
The hash code for this object.
no setterinherited
inputDecorationThemeData InputDecorationThemeData?
Theme for the input decoration.
final
labelText String?
finalinherited
leadingIcon Widget?
Creates a _PlatformMenuPickerData.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showTrailingIcon bool
Whether to show the trailing icon.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

kDefaultShowTrailingIcon → const bool
Default value for showTrailingIcon.