MenuPickerItem<T extends Object> class final

Represents an item in a menu picker.

The iconData will be ignored on iOS if the number of items forces the use of a modal picker as per **medium-to-long lists of items ** from https://developer.apple.com/design/human-interface-guidelines/pickers#Best-practices

Constructors

Creates a menu picker item.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
iconData IconData?
Icon to display for the item.
final
label String?
Label text to display for the item.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited