isEnabled property

bool isEnabled
finalinherited

Whether the button is enabled and can be pressed.

When false, the button will be disabled and onPressed will be ignored.

Implementation

final bool isEnabled;