onLongPress property

VoidCallback? onLongPress
finalinherited

Callback that is called when the button is long-pressed.

If null, the button will not respond to long presses.

Implementation

final VoidCallback? onLongPress;