onPressed property
Callback that is called when the button is pressed.
If null, the button will be disabled.
Implementation
final VoidCallback? onPressed;
Callback that is called when the button is pressed.
If null, the button will be disabled.
final VoidCallback? onPressed;