onHover property
Callback when the hover state changes.
Called when the mouse enters or leaves the button area.
Implementation
final ValueChanged<bool>? onHover;
Callback when the hover state changes.
Called when the mouse enters or leaves the button area.
final ValueChanged<bool>? onHover;