CupertinoExpansionTileData class final

Cupertino-specific configuration for a platform expansion tile.

Maps to properties of the Cupertino expansion tile on iOS.

Constructors

CupertinoExpansionTileData({Key? widgetKey, Widget? title, Widget? child, ExpansibleController? controller, ExpansionTileTransitionMode transitionMode = kDefaultTransitionMode})
Creates Cupertino-specific expansion tile configuration.
const

Properties

child Widget?
The widget to display when the tile is expanded.
finalinherited
controller ExpansibleController?
A controller to manage the expansion state.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title Widget?
The primary content of the tile.
finalinherited
transitionMode ExpansionTileTransitionMode
The transition mode used when expanding or collapsing.
final
widgetKey Key?
A key to identify the widget.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

kDefaultTransitionMode → const ExpansionTileTransitionMode
Default value for transitionMode.