MaterialRadioData<T> class final

Material-specific configuration for a radio button.

Extends PlatformRadioData with Material-only properties.

Inheritance

Constructors

MaterialRadioData({Key? widgetKey, MouseCursor? mouseCursor, bool toggleable = kDefaultToggleable, Color? activeColor, Color? focusColor, FocusNode? focusNode, bool autofocus = kDefaultAutofocus, bool enabled = kDefaultEnabled, RadioGroupRegistry<T>? groupRegistry, WidgetStateProperty<Color?>? fillColor, Color? hoverColor, WidgetStateProperty<Color?>? overlayColor, double? splashRadius, MaterialTapTargetSize? materialTapTargetSize, VisualDensity? visualDensity, WidgetStateProperty<Color?>? backgroundColor, BorderSide? side, WidgetStateProperty<double?>? innerRadius})
Creates Material-specific radio configuration.
const

Properties

activeColor Color?
Color of the radio when active.
finalinherited
autofocus bool
Whether the radio should autofocus.
finalinherited
backgroundColor WidgetStateProperty<Color?>?
Background color as a WidgetStateProperty.
final
enabled bool
Whether the radio is enabled.
finalinherited
fillColor WidgetStateProperty<Color?>?
Fill color as a WidgetStateProperty.
final
focusColor Color?
Color of the radio when focused.
finalinherited
focusNode FocusNode?
Focus node for the radio.
finalinherited
groupRegistry RadioGroupRegistry<T>?
Optional group registry for coordinating radio buttons.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hoverColor Color?
Color when hovering over the radio.
final
innerRadius WidgetStateProperty<double?>?
Inner radius as a WidgetStateProperty.
final
materialTapTargetSize MaterialTapTargetSize?
Material tap target size.
final
mouseCursor MouseCursor?
Mouse cursor when hovering over the radio.
finalinherited
overlayColor WidgetStateProperty<Color?>?
Overlay color as a WidgetStateProperty.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
side BorderSide?
Border side of the radio.
final
splashRadius double?
Splash radius of the radio.
final
toggleable bool
Whether the radio can be toggled off by tapping it again.
finalinherited
visualDensity VisualDensity?
Visual density of the radio.
final
widgetKey Key?
Key applied to the underlying platform widget.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited