CupertinoScrollbarData class final

Cupertino-specific configuration for a platform scrollbar.

Maps to properties of CupertinoScrollbar on iOS.

Constructors

CupertinoScrollbarData({Key? widgetKey, Widget? child, ScrollController? controller, bool? thumbVisibility, double? thickness = kDefaultThickness, Radius? radius = kDefaultRadius, ScrollNotificationPredicate? notificationPredicate, ScrollbarOrientation? scrollbarOrientation, double thicknessWhileDragging = kDefaultThicknessWhileDragging, Radius radiusWhileDragging = kDefaultRadiusWhileDragging, double? mainAxisMargin = kScrollbarMainAxisMargin})
Creates Cupertino-specific scrollbar configuration.
const

Properties

child Widget?
The widget below this widget in the tree.
finalinherited
controller ScrollController?
The scroll controller that the scrollbar should listen to.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
mainAxisMargin double?
Margin along the main axis of the scrollbar.
final
notificationPredicate ScrollNotificationPredicate?
A predicate to filter scroll notifications.
finalinherited
radius Radius?
The radius of the scrollbar thumb's corners.
finalinherited
radiusWhileDragging Radius
Radius of the scrollbar while being dragged.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollbarOrientation ScrollbarOrientation?
The orientation of the scrollbar.
finalinherited
thickness double?
The thickness of the scrollbar thumb.
finalinherited
thicknessWhileDragging double
Thickness of the scrollbar while being dragged.
final
thumbVisibility bool?
Whether the scrollbar thumb should be visible.
finalinherited
widgetKey Key?
A key to identify the widget.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

kDefaultRadius → const Radius
Default value for radius.
kDefaultRadiusWhileDragging → const Radius
Default value for radiusWhileDragging.
kDefaultThickness → const double
Default value for thickness.
kDefaultThicknessWhileDragging → const double
Default value for thicknessWhileDragging.
kScrollbarMainAxisMargin → const double
Default value for mainAxisMargin.