CupertinoNavigationBarData class final

Cupertino-specific configuration for a platform navigation bar.

Maps to properties of CupertinoNavigationBar on iOS.

Constructors

CupertinoNavigationBarData({Widget? title, Color? backgroundColor, Widget? leading, Key? widgetKey, bool automaticallyImplyLeading = kAutoImplyLeading, PreferredSizeWidget? bottom, bool automaticallyImplyMiddle = kAutomaticallyImplyMiddle, String? previousPageTitle, Widget? trailing, Border? border, bool automaticBackgroundVisibility = kAutomaticBackgroundVisibility, bool enableBackgroundFilterBlur = kEnableBackgroundFilterBlur, Brightness? brightness, EdgeInsetsDirectional? padding, bool transitionBetweenRoutes = kTransitionBetweenRoutes})
Creates Cupertino-specific navigation bar configuration.
const
CupertinoNavigationBarData.heroTagOverride({Widget? title, Color? backgroundColor, Widget? leading, Key? widgetKey, bool automaticallyImplyLeading = kAutoImplyLeading, PreferredSizeWidget? bottom, bool automaticallyImplyMiddle = kAutomaticallyImplyMiddle, String? previousPageTitle, Widget? trailing, Border? border, bool automaticBackgroundVisibility = kAutomaticBackgroundVisibility, bool enableBackgroundFilterBlur = kEnableBackgroundFilterBlur, Brightness? brightness, EdgeInsetsDirectional? padding, bool transitionBetweenRoutes = kTransitionBetweenRoutes, Object? heroTag})
To override the default hero tag, use heroTag. Should only be overridden if there are multiple navigation bars per route.
const

Properties

automaticallyImplyLeading bool
Whether to automatically imply a leading widget.
finalinherited
automaticallyImplyMiddle bool
Whether to automatically imply the middle widget.
final
automaticBackgroundVisibility bool
Whether to automatically adjust background visibility.
final
backgroundColor Color?
The background color of the app bar.
finalinherited
border Border?
Border at the bottom of the navigation bar.
final
bottom PreferredSizeWidget?
A widget to display at the bottom of the app bar.
finalinherited
brightness Brightness?
Brightness of the navigation bar.
final
enableBackgroundFilterBlur bool
Whether to enable background filter blur.
final
hashCode int
The hash code for this object.
no setterinherited
heroTag Object?
Hero tag for the navigation bar transition.
final
leading Widget?
A widget to display at the start of the app bar.
finalinherited
padding EdgeInsetsDirectional?
Padding around the navigation bar content.
final
previousPageTitle String?
Title of the previous page (shown in the back button).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title Widget?
The primary widget displayed in the app bar.
finalinherited
trailing Widget?
Trailing widget in the navigation bar.
final
transitionBetweenRoutes bool
Whether to enable hero transitions between routes.
final
widgetKey Key?
A key to identify the app bar widget.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited