localeResolutionCallback property
A callback that is used to resolve the locale when the app is starting.
Implementation
final LocaleResolutionCallback? localeResolutionCallback;
A callback that is used to resolve the locale when the app is starting.
final LocaleResolutionCallback? localeResolutionCallback;