MaterialAppRouterData class final
Material-specific configuration for router-based apps.
Contains properties specific to MaterialApp.router for Android platforms. Extends PlatformAppRouterData with Material-only theme and styling configuration.
- Inheritance
-
- Object
- PlatformAppRouterData
- MaterialAppRouterData
Constructors
-
MaterialAppRouterData({Key? widgetKey, String? title, GenerateAppTitle? onGenerateTitle, Color? color, Locale? locale, Iterable<
LocalizationsDelegate> ? localizationsDelegates, LocaleListResolutionCallback? localeListResolutionCallback, LocaleResolutionCallback? localeResolutionCallback, Iterable<Locale> supportedLocales = kDefaultSupportedLocales, bool showPerformanceOverlay = kDefaultShowPerformanceOverlay, bool checkerboardRasterCacheImages = kDefaultCheckerboardRasterCacheImages, bool checkerboardOffscreenLayers = kDefaultCheckerboardOffscreenLayers, bool showSemanticsDebugger = kDefaultShowSemanticsDebugger, bool debugShowCheckedModeBanner = kDefaultDebugShowCheckedModeBanner, Map<LogicalKeySet, Intent> ? shortcuts, Map<Type, Action< ? actions, String? restorationScopeId, ScrollBehavior? scrollBehavior, TransitionBuilder? builder, RouteInformationProvider? routeInformationProvider, RouteInformationParser<Intent> >Object> ? routeInformationParser, RouterDelegate<Object> ? routerDelegate, RouterConfig<Object> ? routerConfig, BackButtonDispatcher? backButtonDispatcher, GlobalKey<ScaffoldMessengerState> ? scaffoldMessengerKey, ThemeData? theme, ThemeData? darkTheme, ThemeData? highContrastTheme, ThemeData? highContrastDarkTheme, ThemeMode? themeMode, Duration themeAnimationDuration = kMaterialDefaultThemeAnimationDuration, Curve themeAnimationCurve = kMaterialDefaultThemeAnimationCurve, bool debugShowMaterialGrid = kDebugShowMaterialGrid, AnimationStyle? themeAnimationStyle}) -
Creates Material-specific router app configuration.
const
Properties
-
actions
→ Map<
Type, Action< ?Intent> > -
The default map of actions.
finalinherited
- backButtonDispatcher → BackButtonDispatcher?
-
Dispatcher for handling back button presses.
finalinherited
- builder → TransitionBuilder?
-
A builder for the app's content.
finalinherited
- checkerboardOffscreenLayers → bool
-
Whether to checkerboard layers rendered to offscreen bitmaps.
finalinherited
- checkerboardRasterCacheImages → bool
-
Whether to checkerboard raster cache images.
finalinherited
- color → Color?
-
The primary color to use for the application in the OS interface.
finalinherited
- darkTheme → ThemeData?
-
The theme data for the app in dark mode.
final
- debugShowCheckedModeBanner → bool
-
Whether to show a "DEBUG" banner.
finalinherited
- debugShowMaterialGrid → bool
-
Whether to show the Material design grid overlay.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- highContrastDarkTheme → ThemeData?
-
The theme data for high contrast dark mode.
final
- highContrastTheme → ThemeData?
-
The theme data for high contrast light mode.
final
- locale → Locale?
-
The initial locale for the app.
finalinherited
- localeListResolutionCallback → LocaleListResolutionCallback?
-
A callback that is used to resolve the locale when the user changes it.
finalinherited
- localeResolutionCallback → LocaleResolutionCallback?
-
A callback that is used to resolve the locale when the app is starting.
finalinherited
-
localizationsDelegates
→ Iterable<
LocalizationsDelegate> ? -
The delegates for this app's Localizations widget.
finalinherited
-
List of observers for navigation events.
finalinherited
- onGenerateTitle → GenerateAppTitle?
-
A callback to generate the app's title.
finalinherited
-
A callback to listen for navigation notifications.
finalinherited
- restorationScopeId → String?
-
The restoration scope ID for the app.
finalinherited
-
routeInformationParser
→ RouteInformationParser<
Object> ? -
Parser for converting route information to route configuration.
finalinherited
- routeInformationProvider → RouteInformationProvider?
-
Provider for route information from the platform.
finalinherited
-
routerConfig
→ RouterConfig<
Object> ? -
Configuration object for the router.
finalinherited
-
routerDelegate
→ RouterDelegate<
Object> ? -
Delegate for building the navigation stack.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scaffoldMessengerKey
→ GlobalKey<
ScaffoldMessengerState> ? -
Global key for the ScaffoldMessenger.
final
- scrollBehavior → ScrollBehavior?
-
The default scroll behavior for the app.
finalinherited
-
shortcuts
→ Map<
LogicalKeySet, Intent> ? -
The default map of keyboard shortcuts.
finalinherited
- showPerformanceOverlay → bool
-
Whether to show the performance overlay.
finalinherited
- showSemanticsDebugger → bool
-
Whether to show the semantics debugger.
finalinherited
-
supportedLocales
→ Iterable<
Locale> -
The list of locales that this app has been localized for.
finalinherited
- theme → ThemeData?
-
The theme data for the app in light mode.
final
- themeAnimationCurve → Curve
-
Animation curve for theme transitions.
final
- themeAnimationDuration → Duration
-
Duration for theme transitions.
final
- themeAnimationStyle → AnimationStyle?
-
Animation style for theme transitions.
final
- themeMode → ThemeMode?
-
The theme mode to use (light, dark, or system).
final
- title → String?
-
A one-line description of the app for the OS.
finalinherited
- widgetKey → Key?
-
A key to identify the top-level widget of the app.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited