PlatformAppRouterData class final

Platform-shared configuration for router-based apps.

Contains common properties used by both MaterialApp.router and CupertinoApp.router. Use this class when using Flutter's declarative routing API.

Implementers

Constructors

PlatformAppRouterData({Key? widgetKey, String? title, GenerateAppTitle? onGenerateTitle, Color? color, Locale? locale, Iterable<LocalizationsDelegate>? localizationsDelegates, LocaleListResolutionCallback? localeListResolutionCallback, LocaleResolutionCallback? localeResolutionCallback, Iterable<Locale> supportedLocales = kDefaultSupportedLocales, bool showPerformanceOverlay = kDefaultShowPerformanceOverlay, bool checkerboardRasterCacheImages = kDefaultCheckerboardRasterCacheImages, bool checkerboardOffscreenLayers = kDefaultCheckerboardOffscreenLayers, bool showSemanticsDebugger = kDefaultShowSemanticsDebugger, bool debugShowCheckedModeBanner = kDefaultDebugShowCheckedModeBanner, Map<LogicalKeySet, Intent>? shortcuts, Map<Type, Action<Intent>>? actions, String? restorationScopeId, ScrollBehavior? scrollBehavior, TransitionBuilder? builder, bool onNavigationNotification(NavigationNotification)?, RouteInformationProvider? routeInformationProvider, RouteInformationParser<Object>? routeInformationParser, RouterDelegate<Object>? routerDelegate, RouterConfig<Object>? routerConfig, BackButtonDispatcher? backButtonDispatcher, List<NavigatorObserver>? navigatorObservers})
Creates platform router app configuration.
const

Properties

actions Map<Type, Action<Intent>>?
The default map of actions.
finalinherited
backButtonDispatcher BackButtonDispatcher?
Dispatcher for handling back button presses.
final
builder TransitionBuilder?
A builder for the app's content.
finalinherited
checkerboardOffscreenLayers bool
Whether to checkerboard layers rendered to offscreen bitmaps.
finalinherited
checkerboardRasterCacheImages bool
Whether to checkerboard raster cache images.
finalinherited
color Color?
The primary color to use for the application in the OS interface.
finalinherited
debugShowCheckedModeBanner bool
Whether to show a "DEBUG" banner.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
locale Locale?
The initial locale for the app.
finalinherited
localeListResolutionCallback LocaleListResolutionCallback?
A callback that is used to resolve the locale when the user changes it.
finalinherited
localeResolutionCallback LocaleResolutionCallback?
A callback that is used to resolve the locale when the app is starting.
finalinherited
localizationsDelegates Iterable<LocalizationsDelegate>?
The delegates for this app's Localizations widget.
finalinherited
List of observers for navigation events.
final
onGenerateTitle GenerateAppTitle?
A callback to generate the app's title.
finalinherited
onNavigationNotification bool Function(NavigationNotification)?
A callback to listen for navigation notifications.
finalinherited
restorationScopeId String?
The restoration scope ID for the app.
finalinherited
routeInformationParser RouteInformationParser<Object>?
Parser for converting route information to route configuration.
final
routeInformationProvider RouteInformationProvider?
Provider for route information from the platform.
final
routerConfig RouterConfig<Object>?
Configuration object for the router.
final
routerDelegate RouterDelegate<Object>?
Delegate for building the navigation stack.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollBehavior ScrollBehavior?
The default scroll behavior for the app.
finalinherited
shortcuts Map<LogicalKeySet, Intent>?
The default map of keyboard shortcuts.
finalinherited
showPerformanceOverlay bool
Whether to show the performance overlay.
finalinherited
showSemanticsDebugger bool
Whether to show the semantics debugger.
finalinherited
supportedLocales Iterable<Locale>
The list of locales that this app has been localized for.
finalinherited
title String?
A one-line description of the app for the OS.
finalinherited
widgetKey Key?
A key to identify the top-level widget of the app.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited