CupertinoScaffoldData class base

Cupertino-specific scaffold data.

Implementers
Annotations

Constructors

CupertinoScaffoldData({Key? widgetKey, Color? backgroundColor, bool resizeToAvoidBottomInset = kDefaultResizeToAvoidBottomInset, Widget? body, ObstructingPreferredSizeWidget? navigationBar})
Creates Cupertino-specific scaffold data.
const

Properties

backgroundColor Color?
Background color of the scaffold.
finalinherited
body Widget?
The main content of the scaffold.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
The navigation bar to display at the top of the scaffold.
final
resizeToAvoidBottomInset bool
Whether the scaffold should resize to avoid the bottom inset.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widgetKey Key?
Optional key for the scaffold widget.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited