bottomSheetScrimBuilder property
Builder for the scrim that appears behind bottom sheets.
Implementation
final Widget? Function(BuildContext, Animation<double>)? bottomSheetScrimBuilder;
Builder for the scrim that appears behind bottom sheets.
final Widget? Function(BuildContext, Animation<double>)? bottomSheetScrimBuilder;