endDrawerEnableOpenDragGesture property
Whether the end drawer can be opened with a drag gesture.
Implementation
final bool endDrawerEnableOpenDragGesture;
Whether the end drawer can be opened with a drag gesture.
final bool endDrawerEnableOpenDragGesture;