CupertinoTabScaffoldData class final

Cupertino-specific data for a tab-based scaffold.

Inheritance

Constructors

CupertinoTabScaffoldData({Key? widgetKey, Color? backgroundColor, bool resizeToAvoidBottomInset = kDefaultResizeToAvoidBottomInset, Widget? body, ObstructingPreferredSizeWidget? navigationBar, List<TabDestinationData>? tabDestinationsData, CupertinoTabController? controller, IndexedWidgetBuilder? tabBuilder, String? restorationId})
Creates a CupertinoTabScaffoldData.
const

Properties

backgroundColor Color?
Background color of the scaffold.
finalinherited
body Widget?
The main content of the scaffold.
finalinherited
controller CupertinoTabController?
A controller for the tab bar.
final
hashCode int
The hash code for this object.
no setterinherited
The navigation bar to display at the top of the scaffold.
finalinherited
resizeToAvoidBottomInset bool
Whether the scaffold should resize to avoid the bottom inset.
finalinherited
restorationId String?
A restoration ID for the tab scaffold.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tabBuilder IndexedWidgetBuilder?
A builder for the content of each tab.
final
tabDestinationsData List<TabDestinationData>?
A list of destinations to display in the tab bar.
final
widgetKey Key?
Optional key for the scaffold widget.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited