MaterialButtonVariant enum

Material Design button variants available for PlatformButton.

Each variant corresponds to a different Material Design button type:

  • text: Renders as TextButton
  • elevated: Renders as ElevatedButton (default)
  • outlined: Renders as OutlinedButton
  • filled: Renders as FilledButton
Inheritance
Available extensions

Values

text → const MaterialButtonVariant

Renders as a TextButton with no background.

elevated → const MaterialButtonVariant

Renders as an ElevatedButton with elevation and fill.

outlined → const MaterialButtonVariant

Renders as an OutlinedButton with a border.

filled → const MaterialButtonVariant

Renders as a FilledButton with a solid background.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MaterialButtonVariant>
A constant List of the values in this enum, in order of their declaration.