CupertinoButtonVariant enum

Cupertino button variants available for PlatformButton.

Each variant corresponds to a different Cupertino button style:

  • normal: Renders as CupertinoButton (default)
  • filled: Renders as CupertinoButton.filled with a solid background
  • tinted: Renders as CupertinoButton.tinted with a subtle background
Inheritance
Available extensions

Values

normal → const CupertinoButtonVariant

Renders as a standard CupertinoButton with no background.

filled → const CupertinoButtonVariant

Renders as a CupertinoButton.filled with a solid background color.

tinted → const CupertinoButtonVariant

Renders as a CupertinoButton.tinted with a subtle background tint.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CupertinoButtonVariant>
A constant List of the values in this enum, in order of their declaration.