child property

Widget? child
final

The widget to display as the button's label.

This can be a Text widget, Icon, or any other widget. For Material buttons, this is mutually exclusive with providing an icon through materialButtonData.

Implementation

final Widget? child;