cupertinoButtonVariant property
The type of Cupertino button to render on iOS.
Defaults to CupertinoButtonVariant.normal. Each variant renders a different Cupertino button type:
Implementation
final CupertinoButtonVariant cupertinoButtonVariant;
The type of Cupertino button to render on iOS.
Defaults to CupertinoButtonVariant.normal. Each variant renders a different Cupertino button type:
final CupertinoButtonVariant cupertinoButtonVariant;