onLongPress property
Callback that is called when the button is long-pressed. The button is disabled when isEnabled is false, even if onLongPress is provided.
Implementation
final VoidCallback? onLongPress;
Callback that is called when the button is long-pressed. The button is disabled when isEnabled is false, even if onLongPress is provided.
final VoidCallback? onLongPress;