PlatformRadioGroup<T extends Object> class

A platform-adaptive radio group that renders Material RadioGroup on Android

Inheritance

Constructors

PlatformRadioGroup({required PlatformRadioGroupData<T> platformRadioGroupData, PlatformRadioData<T>? platformRadioData, MaterialRadioData<T>? materialRadioData, CupertinoRadioData<T>? cupertinoRadioData, Key? key})
groupValue and onChanged params are deprecated and moved to a parent RadioGroup instead. Breaking the widget hierarchy prevents finding the RadioGroup ancestor. So need to compose the tree directly.
const

Properties

cupertinoRadioData CupertinoRadioData<T>?
Cupertino-specific radio data.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
materialRadioData MaterialRadioData<T>?
Material-specific radio data.
final
platformRadioData PlatformRadioData<T>?
Platform-shared radio data.
final
platformRadioGroupData PlatformRadioGroupData<T>
Platform-shared radio group data.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
buildCupertino(BuildContext context) Widget
Builds the Cupertino (iOS) variant of this widget.
override
buildMaterial(BuildContext context) Widget
Builds the Material Design (Android) variant of this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited