notificationPredicate property
Predicate for determining which scroll notifications to respond to.
Implementation
final ScrollNotificationPredicate? notificationPredicate;
Predicate for determining which scroll notifications to respond to.
final ScrollNotificationPredicate? notificationPredicate;