appData property
Common app data that applies to both platforms.
These properties will be used unless overridden by platform-specific data.
Implementation
final AppData? appData;
Common app data that applies to both platforms.
These properties will be used unless overridden by platform-specific data.
final AppData? appData;