PlatformTabScaffold class

A platform-adaptive tab scaffold that renders a Material scaffold with a navigation bar on Android, and a Cupertino tab scaffold on iOS.

Inheritance

Constructors

PlatformTabScaffold({MaterialTabScaffoldData? materialTabScaffoldData, CupertinoTabScaffoldData? cupertinoTabScaffoldData, List<TabDestinationData>? tabDestinationsData, PlatformTabController? controller, IndexedWidgetBuilder? tabBuilder, Color? backgroundColor, bool resizeToAvoidBottomInset = kDefaultResizeToAvoidBottomInset, String? restorationId, Key? widgetKey, Key? key})
3 modes for state management:
const

Properties

backgroundColor Color?
The background color of the scaffold.
final
controller PlatformTabController?
A controller for the tab bar.
final
cupertinoTabScaffoldData CupertinoTabScaffoldData?
Cupertino-specific data for the tab scaffold.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
materialTabScaffoldData MaterialTabScaffoldData?
Material-specific data for the tab scaffold.
final
resizeToAvoidBottomInset bool
Whether the scaffold should resize to avoid the bottom inset.
final
restorationId String?
A restoration ID to save and restore the state of the scaffold.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tabBuilder IndexedWidgetBuilder?
A builder for the content of each tab.
final
tabDestinationsData List<TabDestinationData>?
A list of destinations to display in the tab bar.
final
widgetKey Key?
Optional key applied to the inner platform-specific widget.
finalinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
buildCupertino(BuildContext context) Widget
Builds the Cupertino (iOS) variant of this widget.
override
buildMaterial(BuildContext context) Widget
Builds the Material Design (Android) variant of this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited