materialBuilder property
Builder function for the Material Design (Android) implementation.
This function is called when the app is running on Android devices. The returned widget will be used as the platform-specific implementation.
Implementation
@protected
final WidgetBuilder materialBuilder;