child property
The child widget to be wrapped with platform-specific behavior.
This widget is passed to the appropriate builder function based on the platform.
Implementation
final Widget child;
The child widget to be wrapped with platform-specific behavior.
This widget is passed to the appropriate builder function based on the platform.
final Widget child;