materialWidgetBuilder property

  1. @protected
Widget Function(BuildContext context, Widget child) materialWidgetBuilder
final

Builder function for the Material Design (Android) implementation.

This function receives the context and child widget and should return a wrapped version of the child with Material-specific styling or behavior.

Implementation

@protected
final Widget Function(BuildContext context, Widget child) materialWidgetBuilder;