CupertinoAlertDialogData class final
Cupertino-specific configuration for a platform alert dialog.
Maps to properties of CupertinoAlertDialog on iOS.
Constructors
-
CupertinoAlertDialogData({Widget? title, Widget? content, List<
Widget> ? actions = kDefaultActions, Key? widgetKey, ScrollController? scrollController, ScrollController? actionScrollController, Duration insetAnimationDuration = kDefaultInsetAnimationDuration, Curve insetAnimationCurve = kDefaultInsetAnimationCurve}) -
Creates Cupertino-specific alert dialog configuration.
const
Properties
-
actions
→ List<
Widget> ? -
A list of widgets to display as actions at the bottom of the dialog.
finalinherited
- actionScrollController → ScrollController?
-
A scroll controller that can be used to control the scrolling of the
actionsin the dialog.final - content → Widget?
-
The main content of the dialog.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- insetAnimationCurve → Curve
-
The curve to use for the animation shown when the dialog slides up.
final
- insetAnimationDuration → Duration
-
The duration of the animation to slide up the dialog.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollController → ScrollController?
-
A scroll controller that can be used to control the scrolling of the
contentin the dialog.final - title → Widget?
-
A title to display at the top of the dialog.
finalinherited
- widgetKey → Key?
-
A key to identify the widget.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
kDefaultActions
→ const List<
Widget> -
Default value for
actions. - kDefaultInsetAnimationCurve → const Curve
- Default value for insetAnimationCurve.
- kDefaultInsetAnimationDuration → const Duration
- Default value for insetAnimationDuration.