CupertinoDatePickerData class final
Cupertino-specific configuration for the platform date picker.
Maps to properties of CupertinoDatePicker shown in a modal popup on iOS.
Constructors
- CupertinoDatePickerData({Offset? anchorPoint, Color? barrierColor = kDefaultModalBarrierColor, bool? barrierDismissible, RouteSettings? routeSettings, SelectableDayPredicate? selectableDayPredicate, TransitionBuilder? builder, ImageFilter? filter, bool? requestFocus, bool semanticsDismissible = kDefaultSemanticsDismissible, Color? backgroundColor, ChangeReportingBehavior changeReportingBehavior = kDefaultChangeReportingBehavior, DatePickerDateOrder? dateOrder, double itemExtent = kDefaultItemExtent, int? maximumYear, int minimumYear = kDefaultMinimumYear, int minuteInterval = kDefaultMinuteInterval, SelectionOverlayBuilder? selectionOverlayBuilder, bool showDayOfWeek = kDefaultShowDayOfWeek, bool showTimeSeparator = kDefaultShowTimeSeparator, bool use24hFormat = kDefaultUse24hFormat})
-
Creates Cupertino-specific date picker configuration.
const
Properties
- anchorPoint → Offset?
-
finalinherited
- backgroundColor → Color?
-
Background color of the date picker.
final
- barrierColor → Color?
-
finalinherited
- barrierDismissible → bool?
-
finalinherited
- builder → TransitionBuilder?
-
finalinherited
- changeReportingBehavior → ChangeReportingBehavior
-
When changes are reported to the callback.
final
- dateOrder → DatePickerDateOrder?
-
Order of the date columns (e.g., day-month-year).
final
- filter → ImageFilter?
-
Image filter applied to the background behind the modal.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemExtent → double
-
Height of each item in the picker wheel.
final
- maximumYear → int?
-
Maximum selectable year.
final
- minimumYear → int
-
Minimum selectable year.
final
- minuteInterval → int
-
Interval between selectable minutes.
final
- requestFocus → bool?
-
Whether the modal should request focus when shown.
final
- routeSettings → RouteSettings?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectableDayPredicate → SelectableDayPredicate?
-
finalinherited
- selectionOverlayBuilder → SelectionOverlayBuilder?
-
Builder for the selection overlay on the picker wheel.
final
- semanticsDismissible → bool
-
Whether the modal can be dismissed via semantics.
final
- showDayOfWeek → bool
-
Whether to show the day of the week.
final
- showTimeSeparator → bool
-
Whether to show the time separator.
final
- use24hFormat → bool
-
Whether to use 24-hour format.
final
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- kDefaultChangeReportingBehavior → const ChangeReportingBehavior
- Default value for changeReportingBehavior.
- kDefaultItemExtent → const double
- Default value for itemExtent.
- kDefaultMinimumYear → const int
- Default value for minimumYear.
- kDefaultMinuteInterval → const int
- Default value for minuteInterval.
- kDefaultModalBarrierColor → const CupertinoDynamicColor
- Default modal barrier color.
- kDefaultSemanticsDismissible → const bool
- Default value for semanticsDismissible.
- kDefaultShowDayOfWeek → const bool
- Default value for showDayOfWeek.
- kDefaultShowTimeSeparator → const bool
- Default value for showTimeSeparator.
- kDefaultUse24hFormat → const bool
- Default value for use24hFormat.