MaterialDialogData class final
Material-specific configuration for showing a dialog.
Extends PlatformDialogData with Material-only properties.
- Inheritance
-
- Object
- PlatformDialogData
- MaterialDialogData
Constructors
- MaterialDialogData({Offset? anchorPoint, Color? barrierColor, bool? barrierDismissible, String? barrierLabel, bool? requestFocus, RouteSettings? routeSettings, AnimationStyle? animationStyle, bool fullscreenDialog = kDefaultFullscreenDialog, TraversalEdgeBehavior? traversalEdgeBehavior, bool useSafeArea = kDefaultUseSafeArea})
-
Creates Material-specific dialog configuration.
const
Properties
- anchorPoint → Offset?
-
The anchor point for the dialog positioning.
finalinherited
- animationStyle → AnimationStyle?
-
Animation style for the dialog transition.
final
- barrierColor → Color?
-
Color of the modal barrier behind the dialog.
finalinherited
- barrierDismissible → bool?
-
Whether tapping the barrier dismisses the dialog.
finalinherited
- barrierLabel → String?
-
Semantic label for the barrier.
finalinherited
- fullscreenDialog → bool
-
Whether the dialog is a fullscreen dialog.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- requestFocus → bool?
-
Whether the dialog should request focus when shown.
finalinherited
- routeSettings → RouteSettings?
-
Route settings for the dialog route.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- traversalEdgeBehavior → TraversalEdgeBehavior?
-
Traversal edge behavior for focus traversal.
final
-
Whether to use the root navigator for the dialog route.
finalinherited
- useSafeArea → bool
-
Whether to wrap the dialog in a SafeArea.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- kDefaultFullscreenDialog → const bool
- Default value for fullscreenDialog.
- kDefaultUseSafeArea → const bool
- Default value for useSafeArea.