PlatformDialogData class final
Platform-shared configuration for showing a dialog.
Contains common properties used by both Material and Cupertino dialogs.
- Implementers
Constructors
- PlatformDialogData({Offset? anchorPoint, Color? barrierColor, bool? barrierDismissible, String? barrierLabel, bool? requestFocus, RouteSettings? routeSettings, })
-
Creates platform dialog configuration.
const
Properties
- anchorPoint → Offset?
-
The anchor point for the dialog positioning.
final
- barrierColor → Color?
-
Color of the modal barrier behind the dialog.
final
- barrierDismissible → bool?
-
Whether tapping the barrier dismisses the dialog.
final
- barrierLabel → String?
-
Semantic label for the barrier.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- requestFocus → bool?
-
Whether the dialog should request focus when shown.
final
- routeSettings → RouteSettings?
-
Route settings for the dialog route.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
Whether to use the root navigator for the dialog route.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited