MenuPickerItem<T extends Object> class
final
Represents an item in a menu picker.
The iconData will be ignored on iOS if the number of items forces the use of a modal picker as per **medium-to-long lists of items ** from https://developer.apple.com/design/human-interface-guidelines/pickers#Best-practices
Constructors
- MenuPickerItem({String? label, IconData? iconData})
-
Creates a menu picker item.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited