onLongPress property
Callback that is called when the button is long-pressed.
If null, the button will not respond to long presses.
Implementation
final VoidCallback? onLongPress;
Callback that is called when the button is long-pressed.
If null, the button will not respond to long presses.
final VoidCallback? onLongPress;