PlatformSliderData class final
Platform-shared configuration for a slider widget.
Contains common properties used by both Material and Cupertino sliders.
- Implementers
Constructors
-
PlatformSliderData({double? value, ValueChanged<
double> ? onChanged, Key? widgetKey, bool isEnabled = true, ValueChanged<double> ? onChangeStart, ValueChanged<double> ? onChangeEnd, double min = kDefaultMin, double max = kDefaultMax, int? divisions, Color? activeColor, Color? thumbColor}) -
Creates platform slider configuration.
const
Properties
- activeColor → Color?
-
Color of the active portion of the slider track.
final
- divisions → int?
-
Number of discrete divisions on the slider.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEnabled → bool
-
Whether the slider is enabled.
final
- max → double
-
Maximum value of the slider.
final
- min → double
-
Minimum value of the slider.
final
-
onChanged
→ ValueChanged<
double> ? -
Callback when the slider value changes.
final
-
onChangeEnd
→ ValueChanged<
double> ? -
Callback when the user stops dragging the slider.
final
-
onChangeStart
→ ValueChanged<
double> ? -
Callback when the user starts dragging the slider.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thumbColor → Color?
-
Color of the slider thumb.
final
- value → double?
-
Current value of the slider.
final
- widgetKey → Key?
-
Key applied to the underlying platform widget.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- kDefaultMax → const double
- Default value for max.
- kDefaultMin → const double
- Default value for min.