MaterialAppBarData class final
Material-specific configuration for a platform app bar.
Maps to properties of AppBar on Android.
Constructors
-
MaterialAppBarData({Widget? title, Color? backgroundColor, Widget? leading, Key? widgetKey, bool automaticallyImplyLeading = kAutoImplyLeading, PreferredSizeWidget? bottom, List<
Widget> ? actions, Widget? flexibleSpace, double? elevation, double? scrolledUnderElevation, ScrollNotificationPredicate notificationPredicate = kDefaultScrollNotificationPredicate, Color? shadowColor, Color? surfaceTintColor, ShapeBorder? shape, Color? foregroundColor, IconThemeData? iconTheme, IconThemeData? actionsIconTheme, bool primary = kDefaultPrimary, bool centerTitle = kCenterTitle, bool excludeHeaderSemantics = kExcludeHeaderSemantics, double? titleSpacing, double toolbarOpacity = kToolbarOpacity, double bottomOpacity = kBottomOpacity, double? toolbarHeight, double? leadingWidth, TextStyle? toolbarTextStyle, TextStyle? titleTextStyle, SystemUiOverlayStyle? systemOverlayStyle, bool forceMaterialTransparency = kForceMaterialTransparency, bool useDefaultSemanticsOrder = kUseDefaultSemanticsOrder, Clip? clipBehavior, EdgeInsetsGeometry? actionsPadding, bool animateColor = kAnimateColor}) -
Creates Material-specific app bar configuration.
const
Properties
-
actions
→ List<
Widget> ? -
Action widgets displayed in the app bar.
final
- actionsIconTheme → IconThemeData?
-
Icon theme for the action icons.
final
- actionsPadding → EdgeInsetsGeometry?
-
Padding around the actions.
final
- animateColor → bool
-
Whether to animate color changes.
final
- automaticallyImplyLeading → bool
-
Whether to automatically imply a leading widget.
finalinherited
- backgroundColor → Color?
-
The background color of the app bar.
finalinherited
- bottom → PreferredSizeWidget?
-
A widget to display at the bottom of the app bar.
finalinherited
- bottomOpacity → double
-
Opacity of the bottom widget.
final
- centerTitle → bool
-
Whether the title should be centered.
final
- clipBehavior → Clip?
-
Clip behavior for the app bar.
final
- elevation → double?
-
Elevation of the app bar.
final
- excludeHeaderSemantics → bool
-
Whether to exclude header semantics.
final
- flexibleSpace → Widget?
-
Widget displayed behind the toolbar and tab bar.
final
- forceMaterialTransparency → bool
-
Whether to force Material transparency.
final
- foregroundColor → Color?
-
Foreground color of the app bar.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconTheme → IconThemeData?
-
Icon theme for the app bar icons.
final
- leading → Widget?
-
A widget to display at the start of the app bar.
finalinherited
- leadingWidth → double?
-
Width of the leading widget.
final
- notificationPredicate → ScrollNotificationPredicate
-
Predicate for scroll notifications.
final
- primary → bool
-
Whether this is the primary app bar (affects status bar area).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrolledUnderElevation → double?
-
Elevation when scrolled under.
final
- shadowColor → Color?
-
Shadow color of the app bar.
final
- shape → ShapeBorder?
-
Shape of the app bar.
final
- surfaceTintColor → Color?
-
Surface tint color of the app bar.
final
- systemOverlayStyle → SystemUiOverlayStyle?
-
System UI overlay style.
final
- title → Widget?
-
The primary widget displayed in the app bar.
finalinherited
- titleSpacing → double?
-
Spacing around the title.
final
- titleTextStyle → TextStyle?
-
Text style for the title.
final
- toolbarHeight → double?
-
Height of the toolbar.
final
- toolbarOpacity → double
-
Opacity of the toolbar.
final
- toolbarTextStyle → TextStyle?
-
Text style for the toolbar.
final
- useDefaultSemanticsOrder → bool
-
Whether to use default semantics order.
final
- widgetKey → Key?
-
A key to identify the app bar widget.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- kAnimateColor → const bool
- Default value for animateColor.
- kBottomOpacity → const double
- Default value for bottomOpacity.
- kCenterTitle → const bool
- Default value for centerTitle.
- kDefaultPrimary → const bool
- Default value for primary.
- kDefaultScrollNotificationPredicate → const bool Function(ScrollNotification notification)
- Default value for notificationPredicate.
- kExcludeHeaderSemantics → const bool
- Default value for excludeHeaderSemantics.
- kForceMaterialTransparency → const bool
- Default value for forceMaterialTransparency.
- kToolbarOpacity → const double
- Default value for toolbarOpacity.
- kUseDefaultSemanticsOrder → const bool
- Default value for useDefaultSemanticsOrder.