MaterialScaffoldData class base
Material-specific scaffold data.
Contains properties specific to Material Design Scaffold widgets.
- Implementers
- Annotations
Constructors
- MaterialScaffoldData({Key? widgetKey, Color? backgroundColor, bool resizeToAvoidBottomInset = kDefaultResizeToAvoidBottomInset, Widget? body, PreferredSizeWidget? appBar, Widget? floatingActionButton, FloatingActionButtonLocation? floatingActionButtonLocation, FloatingActionButtonAnimator? floatingActionButtonAnimator, Widget? drawer, void onDrawerChanged(bool)?, Widget? endDrawer, void onEndDrawerChanged(bool)?, Widget? bottomSheet, bool primary = kPrimary, DragStartBehavior drawerDragStartBehavior = kDrawerDragStartBehavior, bool extendBody = kExtendBody, bool drawerBarrierDismissible = kDrawerBarrierDismissible, bool extendBodyBehindAppBar = kExtendBodyBehindAppBar, Color? drawerScrimColor, double? drawerEdgeDragWidth, bool drawerEnableOpenDragGesture = kDrawerEnableOpenDragGesture, bool endDrawerEnableOpenDragGesture = kEndDrawerEnableOpenDragGesture, String? restorationId})
-
Creates Material-specific scaffold data.
const
-
MaterialScaffoldData.withBottomSheetScrimBuilder({required Widget? bottomSheetScrimBuilder(BuildContext, Animation<
double> )?, Key? widgetKey, Color? backgroundColor, bool resizeToAvoidBottomInset = kDefaultResizeToAvoidBottomInset, Widget? body, PreferredSizeWidget? appBar, Widget? floatingActionButton, FloatingActionButtonLocation? floatingActionButtonLocation, FloatingActionButtonAnimator? floatingActionButtonAnimator, Widget? drawer, void onDrawerChanged(bool)?, Widget? endDrawer, void onEndDrawerChanged(bool)?, Widget? bottomSheet, bool primary = kPrimary, DragStartBehavior drawerDragStartBehavior = kDrawerDragStartBehavior, bool extendBody = kExtendBody, bool drawerBarrierDismissible = kDrawerBarrierDismissible, bool extendBodyBehindAppBar = kExtendBodyBehindAppBar, Color? drawerScrimColor, double? drawerEdgeDragWidth, bool drawerEnableOpenDragGesture = kDrawerEnableOpenDragGesture, bool endDrawerEnableOpenDragGesture = kEndDrawerEnableOpenDragGesture, String? restorationId}) -
Creates Material-specific scaffold data with a bottom sheet scrim builder.
const
Properties
- appBar → PreferredSizeWidget?
-
The app bar to display at the top of the scaffold.
final
- backgroundColor → Color?
-
Background color of the scaffold.
finalinherited
- body → Widget?
-
The main content of the scaffold.
finalinherited
- bottomSheet → Widget?
-
The bottom sheet to display.
final
-
bottomSheetScrimBuilder
→ Widget? Function(BuildContext, Animation<
double> )? -
Builder for the scrim that appears behind bottom sheets.
final
- drawer → Widget?
-
The drawer to display from the left side.
final
- drawerBarrierDismissible → bool
-
Whether the drawer barrier can be dismissed.
final
- drawerDragStartBehavior → DragStartBehavior
-
The drag start behavior for the drawer.
final
- drawerEdgeDragWidth → double?
-
Width of the area that responds to drawer drag gestures.
final
- drawerEnableOpenDragGesture → bool
-
Whether the drawer can be opened with a drag gesture.
final
- drawerScrimColor → Color?
-
Color of the scrim that appears behind the drawer.
final
- endDrawer → Widget?
-
The drawer to display from the right side.
final
- endDrawerEnableOpenDragGesture → bool
-
Whether the end drawer can be opened with a drag gesture.
final
- extendBody → bool
-
Whether to extend the body behind the app bar.
final
- extendBodyBehindAppBar → bool
-
Whether to extend the body behind the app bar.
final
- floatingActionButton → Widget?
-
The floating action button to display.
final
- floatingActionButtonAnimator → FloatingActionButtonAnimator?
-
The animator for the floating action button.
final
- floatingActionButtonLocation → FloatingActionButtonLocation?
-
The location of the floating action button.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- onDrawerChanged → void Function(bool)?
-
Callback when the drawer state changes.
final
- onEndDrawerChanged → void Function(bool)?
-
Callback when the end drawer state changes.
final
-
Alignment for the persistent footer buttons.
final
-
Buttons to display at the bottom of the scaffold.
final
-
Decoration for the persistent footer buttons area.
final
- primary → bool
-
Whether this scaffold is the primary scaffold.
final
- resizeToAvoidBottomInset → bool
-
Whether the scaffold should resize to avoid the bottom inset.
finalinherited
- restorationId → String?
-
Restoration ID for saving and restoring scaffold state.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widgetKey → Key?
-
Optional key for the scaffold widget.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- Default value for persistent footer alignment.
- kDrawerBarrierDismissible → const bool
- Default value for drawer barrier dismissible.
- kDrawerDragStartBehavior → const DragStartBehavior
- Default value for drawer drag start behavior.
- kDrawerEnableOpenDragGesture → const bool
- Default value for drawer enable open drag gesture.
- kEndDrawerEnableOpenDragGesture → const bool
- Default value for end drawer enable open drag gesture.
- kExtendBody → const bool
- Default value for extend body.
- kExtendBodyBehindAppBar → const bool
- Default value for extend body behind app bar.
- kPrimary → const bool
- Default value for primary scaffold.