MaterialTabScaffoldData class final
Material-specific data for a tab-based scaffold.
- Inheritance
-
- Object
- MaterialScaffoldData
- MaterialTabScaffoldData
Constructors
-
MaterialTabScaffoldData({Key? widgetKey, Color? backgroundColor, bool resizeToAvoidBottomInset = kDefaultResizeToAvoidBottomInset, Widget? body, Widget? floatingActionButton, FloatingActionButtonLocation? floatingActionButtonLocation, FloatingActionButtonAnimator? floatingActionButtonAnimator, Widget? drawer, void onDrawerChanged(bool)?, Widget? endDrawer, void onEndDrawerChanged(bool)?, Widget? bottomSheet, bool primary = MaterialScaffoldData.kPrimary, DragStartBehavior drawerDragStartBehavior = MaterialScaffoldData.kDrawerDragStartBehavior, bool extendBody = MaterialScaffoldData.kExtendBody, bool drawerBarrierDismissible = MaterialScaffoldData.kDrawerBarrierDismissible, bool extendBodyBehindAppBar = MaterialScaffoldData.kExtendBodyBehindAppBar, Color? drawerScrimColor, double? drawerEdgeDragWidth, bool drawerEnableOpenDragGesture = MaterialScaffoldData.kDrawerEnableOpenDragGesture, bool endDrawerEnableOpenDragGesture = MaterialScaffoldData.kEndDrawerEnableOpenDragGesture, String? restorationId, List<
TabDestinationData> ? tabDestinationsData, TabController? controller, IndexedWidgetBuilder? tabBuilder}) -
Creates a MaterialTabScaffoldData.
const
Properties
- appBar → PreferredSizeWidget?
-
The app bar to display at the top of the scaffold.
finalinherited
- backgroundColor → Color?
-
Background color of the scaffold.
finalinherited
- body → Widget?
-
The main content of the scaffold.
finalinherited
- bottomSheet → Widget?
-
The bottom sheet to display.
finalinherited
-
bottomSheetScrimBuilder
→ Widget? Function(BuildContext, Animation<
double> )? -
Builder for the scrim that appears behind bottom sheets.
finalinherited
- controller → TabController?
-
A controller for the tab bar.
final
- drawer → Widget?
-
The drawer to display from the left side.
finalinherited
- drawerBarrierDismissible → bool
-
Whether the drawer barrier can be dismissed.
finalinherited
- drawerDragStartBehavior → DragStartBehavior
-
The drag start behavior for the drawer.
finalinherited
- drawerEdgeDragWidth → double?
-
Width of the area that responds to drawer drag gestures.
finalinherited
- drawerEnableOpenDragGesture → bool
-
Whether the drawer can be opened with a drag gesture.
finalinherited
- drawerScrimColor → Color?
-
Color of the scrim that appears behind the drawer.
finalinherited
- endDrawer → Widget?
-
The drawer to display from the right side.
finalinherited
- endDrawerEnableOpenDragGesture → bool
-
Whether the end drawer can be opened with a drag gesture.
finalinherited
- extendBody → bool
-
Whether to extend the body behind the app bar.
finalinherited
- extendBodyBehindAppBar → bool
-
Whether to extend the body behind the app bar.
finalinherited
- floatingActionButton → Widget?
-
The floating action button to display.
finalinherited
- floatingActionButtonAnimator → FloatingActionButtonAnimator?
-
The animator for the floating action button.
finalinherited
- floatingActionButtonLocation → FloatingActionButtonLocation?
-
The location of the floating action button.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- onDrawerChanged → void Function(bool)?
-
Callback when the drawer state changes.
finalinherited
- onEndDrawerChanged → void Function(bool)?
-
Callback when the end drawer state changes.
finalinherited
-
Alignment for the persistent footer buttons.
finalinherited
-
Buttons to display at the bottom of the scaffold.
finalinherited
-
Decoration for the persistent footer buttons area.
finalinherited
- primary → bool
-
Whether this scaffold is the primary scaffold.
finalinherited
- resizeToAvoidBottomInset → bool
-
Whether the scaffold should resize to avoid the bottom inset.
finalinherited
- restorationId → String?
-
Restoration ID for saving and restoring scaffold state.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tabBuilder → IndexedWidgetBuilder?
-
A builder for the content of each tab.
final
-
tabDestinationsData
→ List<
TabDestinationData> ? -
A list of destinations to display in the tab bar.
final
- widgetKey → Key?
-
Optional key for the scaffold widget.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited