TabDestinationData class final
Data for a single destination in a tab-based navigation structure.
Constructors
- TabDestinationData({required Widget inactiveIcon, Widget? view, Widget? activeIcon, String label = '', String? tooltip, Key? key})
-
Creates a TabDestinationData.
const
Properties
- activeIcon → Widget?
-
The icon to display when the destination is active.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inactiveIcon → Widget
-
The icon to display when the destination is inactive.
final
- key → Key?
-
An optional key for the destination.
final
- label → String
-
A label to display for the destination.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tooltip → String?
-
A tooltip to display for the destination.
final
- view → Widget?
-
The widget to display as the content for this destination.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited