PlatformTheme class final
Provides access to platform-specific theme colors.
Constructors
- PlatformTheme.of(BuildContext context)
-
Creates a PlatformTheme with the given
context.const
Properties
- barBackgroundColor → Color
-
The background color of the app bar.
no setter
- context → BuildContext
-
The build context to use for retrieving theme data.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- primaryColor → Color
-
The primary color of the theme.
no setter
- primaryContrastingColor → Color
-
A color that contrasts with the primary color.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scaffoldBackgroundColor → Color
-
The background color of the scaffold.
no setter
- selectionHandleColor → Color
-
The color of the selection handles.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited