CupertinoSearchBarData class final
Cupertino-specific configuration for a search bar widget.
Maps to properties of CupertinoSearchTextField on iOS.
- Inheritance
-
- Object
- PlatformSearchBarData
- CupertinoSearchBarData
Constructors
-
CupertinoSearchBarData({Key? widgetKey, TextEditingController? controller, String? hintText, Widget? leading = kDefaultLeading, VoidCallback? onTap, ValueChanged<
String> ? onChanged, ValueChanged<String> ? onSubmitted, TextInputType? keyboardType, bool autoFocus = kDefaultAutoFocus, FocusNode? focusNode, bool enabled = kDefaultEnabled, TextStyle? style, TextStyle? placeholderStyle, BoxDecoration? decoration, Color? backgroundColor, BorderRadius? borderRadius, EdgeInsetsGeometry padding = kDefaultPadding, Color itemColor = kDefaultItemColor, double itemSize = kDefaultItemSize, EdgeInsetsGeometry prefixInsets = kDefaultPrefixInsets, EdgeInsetsGeometry suffixInsets = kDefaultSuffixInsets, Icon suffixIcon = kDefaultSuffixIcon, OverlayVisibilityMode suffixMode = kDefaultSuffixMode, VoidCallback? onSuffixTap, String? restorationId, SmartQuotesType? smartQuotesType, SmartDashesType? smartDashesType, bool enableIMEPersonalizedLearning = kDefaultEnableIMEPersonalizedLearning, bool autocorrect = kDefaultAutocorrect, double cursorWidth = kDefaultCursorWidth, double? cursorHeight, Radius cursorRadius = kDefaultCursorRadius, bool cursorOpacityAnimates = kDefaultCursorOpacityAnimates, Color? cursorColor}) -
Creates Cupertino-specific search bar configuration.
const
Properties
- autocorrect → bool
-
Whether to enable autocorrect.
final
- autoFocus → bool
-
Whether the search bar should autofocus.
finalinherited
- backgroundColor → Color?
-
Background color of the search bar.
final
- borderRadius → BorderRadius?
-
Border radius of the search bar.
final
- controller → TextEditingController?
-
Text editing controller for the search input.
finalinherited
- cursorColor → Color?
-
Color of the cursor.
final
- cursorHeight → double?
-
Height of the cursor.
final
- cursorOpacityAnimates → bool
-
Whether the cursor opacity animates.
final
- cursorRadius → Radius
-
Radius of the cursor.
final
- cursorWidth → double
-
Width of the cursor.
final
- decoration → BoxDecoration?
-
Box decoration for the search bar.
final
- enabled → bool
-
Whether the search bar is enabled.
finalinherited
- enableIMEPersonalizedLearning → bool
-
Whether to enable IME personalized learning.
final
- focusNode → FocusNode?
-
Focus node for the search bar.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hintText → String?
-
Hint text displayed when the search bar is empty.
finalinherited
- itemColor → Color
-
Color of prefix and suffix items.
final
- itemSize → double
-
Size of prefix and suffix items.
final
- keyboardType → TextInputType?
-
Keyboard type for the search input.
finalinherited
- leading → Widget?
-
Leading widget (e.g., a search icon).
finalinherited
-
onChanged
→ ValueChanged<
String> ? -
Callback when the search text changes.
finalinherited
-
onSubmitted
→ ValueChanged<
String> ? -
Callback when the search text is submitted.
finalinherited
- onSuffixTap → VoidCallback?
-
Callback when the suffix icon is tapped.
final
- onTap → VoidCallback?
-
Callback when the search bar is tapped.
finalinherited
- padding → EdgeInsetsGeometry
-
Padding around the search bar content.
final
- placeholderStyle → TextStyle?
-
Text style for the placeholder text.
final
- prefixInsets → EdgeInsetsGeometry
-
Insets for the prefix widget.
final
- restorationId → String?
-
Restoration ID for state restoration.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- smartDashesType → SmartDashesType?
-
Smart dashes type for the search input.
final
- smartQuotesType → SmartQuotesType?
-
Smart quotes type for the search input.
final
- style → TextStyle?
-
Text style for the search input.
final
- suffixIcon → Icon
-
Icon displayed as the suffix.
final
- suffixInsets → EdgeInsetsGeometry
-
Insets for the suffix widget.
final
- suffixMode → OverlayVisibilityMode
-
When the suffix icon is visible.
final
- widgetKey → Key?
-
Key applied to the underlying platform widget.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- kDefaultAutocorrect → const bool
- Default value for autocorrect.
- kDefaultCursorOpacityAnimates → const bool
- Default value for cursorOpacityAnimates.
- kDefaultCursorRadius → const Radius
- Default value for cursorRadius.
- kDefaultCursorWidth → const double
- Default value for cursorWidth.
- kDefaultEnableIMEPersonalizedLearning → const bool
- Default value for enableIMEPersonalizedLearning.
- kDefaultItemColor → const CupertinoDynamicColor
- Default value for itemColor.
- kDefaultItemSize → const double
- Default value for itemSize.
- kDefaultLeading → const Icon
- Default value for leading.
- kDefaultPadding → const EdgeInsets
- Default value for padding.
- kDefaultPrefixInsets → const EdgeInsetsDirectional
- Default value for prefixInsets.
- kDefaultSuffixIcon → const Icon
- Default value for suffixIcon.
- kDefaultSuffixInsets → const EdgeInsetsDirectional
- Default value for suffixInsets.
- kDefaultSuffixMode → const OverlayVisibilityMode
- Default value for suffixMode.