MaterialSliderData class final
Material-specific configuration for a slider widget.
Extends PlatformSliderData with Material-only properties.
- Inheritance
-
- Object
- PlatformSliderData
- MaterialSliderData
Constructors
-
MaterialSliderData({double? value, ValueChanged<
double> ? onChanged, Key? widgetKey, bool isEnabled = true, ValueChanged<double> ? onChangeStart, ValueChanged<double> ? onChangeEnd, double min = kDefaultMin, double max = kDefaultMax, int? divisions, Color? activeColor, Color? thumbColor, double? secondaryTrackValue, String? label, Color? inactiveColor, Color? secondaryActiveColor, WidgetStateProperty<Color> ? overlayColor, MouseCursor? mouseCursor, SemanticFormatterCallback? semanticFormatterCallback, FocusNode? focusNode, bool autofocus = kDefaultAutofocus, SliderInteraction? allowedInteraction, EdgeInsetsGeometry? padding}) -
Creates Material-specific slider configuration.
const
Properties
- activeColor → Color?
-
Color of the active portion of the slider track.
finalinherited
- allowedInteraction → SliderInteraction?
-
Allowed interaction type for the slider.
final
- autofocus → bool
-
Whether the slider should autofocus.
final
- divisions → int?
-
Number of discrete divisions on the slider.
finalinherited
- focusNode → FocusNode?
-
Focus node for the slider.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inactiveColor → Color?
-
Color of the inactive portion of the slider track.
final
- isEnabled → bool
-
Whether the slider is enabled.
finalinherited
- label → String?
-
Label displayed above the thumb.
final
- max → double
-
Maximum value of the slider.
finalinherited
- min → double
-
Minimum value of the slider.
finalinherited
- mouseCursor → MouseCursor?
-
Mouse cursor when hovering over the slider.
final
-
onChanged
→ ValueChanged<
double> ? -
Callback when the slider value changes.
finalinherited
-
onChangeEnd
→ ValueChanged<
double> ? -
Callback when the user stops dragging the slider.
finalinherited
-
onChangeStart
→ ValueChanged<
double> ? -
Callback when the user starts dragging the slider.
finalinherited
-
overlayColor
→ WidgetStateProperty<
Color> ? -
Overlay color as a WidgetStateProperty.
final
- padding → EdgeInsetsGeometry?
-
Padding around the slider.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryActiveColor → Color?
-
Color of the secondary active track.
final
- secondaryTrackValue → double?
-
Value for the secondary track (e.g., buffered progress).
final
- semanticFormatterCallback → SemanticFormatterCallback?
-
Callback for formatting the semantic value.
final
- thumbColor → Color?
-
Color of the slider thumb.
finalinherited
- value → double?
-
Current value of the slider.
finalinherited
- widgetKey → Key?
-
Key applied to the underlying platform widget.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- kDefaultAutofocus → const bool
- Default value for autofocus.