PlatformAlertDialogActionButton class
A platform-adaptive dialog action button that renders TextButton on Android and CupertinoDialogAction on iOS.
This widget automatically selects the appropriate button implementation based on the target platform:
- On Android: renders a Material Design TextButton
- On iOS: renders a CupertinoDialogAction
Default actions will have bold text but only on cupertino.
Destructive actions will be rendered in red text on cupertino and with a red filled background on material.
Using the context of onPressed allows to have a reference to the dialog context.
Customize the ButtonTheme.colorScheme.error to change the color of destructive actions.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- PlatformWidgetBase
- PlatformWidgetKeyedBase
- PlatformWidgetKeyedBuilderBase
- PlatformAlertDialogActionButton
Constructors
-
PlatformAlertDialogActionButton({required Widget child, Key? widgetKey, Key? key, ValueChanged<
BuildContext> ? onPressed, bool isDestructiveAction = false, bool isDefaultAction = false}) -
Creates a new platform aware dialog action.
const
Properties
- child → Widget
-
The child widget to wrap with platform-specific behavior.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDefaultAction → bool
-
Whether this is the default action.
final
- isDestructiveAction → bool
-
Whether this action represents a destructive action.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onPressed
→ ValueChanged<
BuildContext> ? -
Callback when the action button is pressed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widgetKey → Key?
-
Optional key applied to the inner platform-specific widget.
finalinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
inherited
-
buildCupertino(
BuildContext context) → Widget -
Builds the Cupertino (iOS) variant of this widget.
override
-
buildMaterial(
BuildContext context) → Widget -
Builds the Material Design (Android) variant of this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited