PlatformApp class
A platform-adaptive app widget that renders MaterialApp on Android and CupertinoApp on iOS.
This widget automatically selects the appropriate app implementation based on the target platform:
- On Android: renders MaterialApp
- On iOS: renders CupertinoApp
The app can be configured with platform-specific data through materialAppData and cupertinoAppData, or with common properties through appData.
Use the named constructor PlatformApp.router for apps using Flutter's router API.
Example:
PlatformApp(
appData: AppData(
title: 'My App',
home: MyHomePage(),
),
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- PlatformWidgetBase
- PlatformApp
Constructors
- PlatformApp({AppData? appData, MaterialAppData? materialAppData, CupertinoAppData? cupertinoAppData, Key? key})
-
Creates a platform-adaptive app.
const
- PlatformApp.router({PlatformAppRouterData? appRouterData, MaterialAppRouterData? materialAppRouterData, CupertinoAppRouterData? cupertinoAppRouterData, Key? key})
-
Creates a platform-adaptive app using Flutter's router API.
const
Properties
- appData → AppData?
-
Common app data that applies to both platforms.
final
- appRouterData → PlatformAppRouterData?
-
Common router app data that applies to both platforms.
final
- cupertinoAppData → CupertinoAppData?
-
Platform-specific data for CupertinoApp.
final
- cupertinoAppRouterData → CupertinoAppRouterData?
-
Platform-specific data for CupertinoApp.router.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- materialAppData → MaterialAppData?
-
Platform-specific data for MaterialApp.
final
- materialAppRouterData → MaterialAppRouterData?
-
Platform-specific data for MaterialApp.router.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
inherited
-
buildCupertino(
BuildContext context) → CupertinoApp -
Builds the Cupertino (iOS) variant of this widget.
override
-
buildMaterial(
BuildContext context) → MaterialApp -
Builds the Material Design (Android) variant of this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited