widgets/platform_widget library
Classes
- PlatformWidget
- A platform-adaptive widget that provides different implementations for Material and Cupertino.
- PlatformWidgetBuilder
- A platform-adaptive widget that wraps a child widget with platform-specific behavior.