cupertinoBuilder property
Builder function for the Cupertino (iOS) implementation.
This function is called when the app is running on iOS devices. The returned widget will be used as the platform-specific implementation.
Implementation
@protected
final WidgetBuilder cupertinoBuilder;